A Command Interpreter with support for used defined commands, subsystems, macros, help and parameter parsing.

Revision:
22:5192a468d7fa
Parent:
21:d22068e2bbd1
Child:
23:73a4f087c1b9
--- a/cmdb.h	Tue Nov 22 12:41:57 2011 +0000
+++ b/cmdb.h	Tue Nov 22 12:57:13 2011 +0000
@@ -499,7 +499,20 @@
      */
     int printsection(const char *section);
 
-      /** printerror prints an inifile Error Section Header and Error Msg Key=Value pair.
+    /** printmsg prints an inifile Msg Key=Value pair.
+     *  like:
+     *
+     *  Msg={msg}\r\n
+     *
+     *  Usage: cmdb.printmsg("Validation successfull");
+     *
+     *  @parm msg the msg to print.
+     *
+     *  @returns the printf return value.
+     */
+    int   Cmdb::printmsg(const char *msg);
+
+    /** printerror prints an inifile Error Section Header and Error Msg Key=Value pair.
      *  like:
      *
      *  [Error]\r\nmsg={errormsg}\r\n
@@ -511,7 +524,7 @@
      *  @returns the printf return value.
      */
     int printerror(const char *errormsg);
-        
+
     /** printvalue prints an inifile Key/Value Pair
      *  like:
      *